@@ -50,7 +50,7 @@ class Cogent4D:
         self.numGhostY = numGhostY
         self.time = time
 
-def importData4D(fileName) -> Cogent4D:
+def import_4d_data_from_hdf5(fileName) -> Cogent4D:
     '''Import 4D data from single COGENT output file.
   
      Input is an address string to the HDF5 file.
@@ -317,7 +317,7 @@ class Cogent2D:
         self.numGhostY = numGhostY
         self.time = time
 
-def importData2D(fileName) -> Cogent2D:
+def import_2d_data_from_hdf5(fileName) -> Cogent2D:
     '''Import 2D data from single COGENT output file.
     
     Input is an address string to the HDF5 file.
@@ -489,10 +489,10 @@ def importData2D(fileName) -> Cogent2D:
                     numGhostY = ghost['intvectj'],
                     time = time)
 
-def parseInputDeck(fileName):
+def parse_input_deck(fileName) -> dict:
     '''Reads input deck line-by-line and
     turns it into a Python dictionary'''
-    def dictFromKeys(keys, value):
+    def dict_from_keys(keys, value):
         dictionary = nest = {}
         for key in keys[:-1]:
             nest[key] = {}
@@ -500,7 +500,7 @@ def parseInputDeck(fileName):
         nest[keys[-1]] = value
         return dictionary
 
-    def isfloat(string):
+    def is_float(string):
         try:
             float(string)
             return True
@@ -533,7 +533,7 @@ def parseInputDeck(fileName):
             value = True
         elif valueString == 'false':
             value = False
-        elif isfloat(valueString):
+        elif is_float(valueString):
             value = float(valueString)
         elif valueString.count('"') == 2:
             value = valueString.strip('"') #quotated name
@@ -542,7 +542,7 @@ def parseInputDeck(fileName):
             valueString.count('"') % 2 == 0:
             value = [x for x in \
              valueString.replace(' ','').split('"') if x != '']
-        elif all([isfloat(x) for x in valueString.split(' ')]):
+        elif all([is_float(x) for x in valueString.split(' ')]):
             value = [float(x) for x in valueString.split(' ')]
         else:
             value = valueString #no parsing rule found
@@ -557,7 +557,7 @@ def parseInputDeck(fileName):
                 if len(keys[keyID+1:]) == 0:
                     nest[key] = value
                 else:
-                    nest[key] = dictFromKeys(keys[keyID+1:],value)
+                    nest[key] = dict_from_keys(keys[keyID+1:],value)
                 break
             else:
                 nest = nest[key]
@@ -572,7 +572,7 @@ def parseInputDeck(fileName):
         inputDeck = parseStringToInputDeck(inputDeck,line[:-1])
     return inputDeck
 
-def addInputDeckToHDF5File(inputDeckFile, HDF5File):
+def add_input_deck_to_hdf5(inputDeckFile, HDF5File):
     '''Read input deck from inputDeckFile and save it
     to attributes of HDF5file'''
     f = h5py.File(HDF5File, "r+")
@@ -580,7 +580,7 @@ def addInputDeckToHDF5File(inputDeckFile, HDF5File):
      'This HDF5 file already stores an inputDeck.'
     f.attrs['inputDeck'] = open(inputDeckFile,'r').read()
 
-def removeInputDeckFromHDF5File(HDF5File):
+def remove_input_deck_from_hdf5(HDF5File):
     '''Delets input deck from attributes of HDF5File'''
     f = h5py.File(HDF5File,"r+")
     assert f.attrs.get('inputDeck',None) is not None, \
